/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 OW2 Consortium, http://www.ow2.org/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: PetalsAdminServiceMBean.java 16:40:52 alouis $
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.jmx.api;

import javax.management.MalformedObjectNameException;
import javax.management.ObjectName;


/**
 * This interface is the interface of the PEtALS Admin Service.
 * 
 * @author cdeneux - Capgemini Sud
 */
public interface IPetalsAdminService {

    public static class DomainKeyNames {
        /**
         * Domain key names: domain name
         */
        public static final String CONF_DOMAIN_NAME = "domainName";

        /**
         * Domain key names: domain mode
         */
        public static final String CONF_DOMAIN_MODE = "domainMode";

        /**
         * Domain key names: multicast IP address
         */
        public static final String CONF_NETWORK_MULTICAST_IP = "multicastIp";

        /**
         * Domain key names: multicast port
         */
        public static final String CONF_NETWORK_MULTICAST_PORT = "multicastPort";

        /**
         * Domain key names: JNDI Factory
         */
        public static final String CONF_JNDI_FACTORY = "jndiFactory";

        /**
         * Domain key names: JNDI Host name
         */
        public static final String CONF_JNDI_HOST = "jndiHost";

        /**
         * Domain key names: JNDI port
         */
        public static final String CONF_JNDI_PORT = "jndiPort";

        private DomainKeyNames() {
            // NOP
        }
    }

    public static class ContainerKeyNames {
        /**
         * Container key names: Container Name
         */
        public static final String CONF_CONTAINER_NAME = "containerName";

        /**
         * Container key names: Container Host Name
         */
        public static final String CONF_HOST = "host";

        /**
         * Container key names: Network bind port
         */
        public static final String CONF_NETWORK_BIND_PORT = "networkBindPort";

        /**
         * Container key names: JMX login
         */
        public static final String CONF_JMX_LOGIN = "jmxLogin";

        /**
         * Container key names: JMX server port
         */
        public static final String CONF_JMX_RMI_PORT = "jmxRMIPort";

        /**
         * Container key names: MX4J HTTP port
         */
        public static final String CONF_JMX_HTTP_PORT = "jmxHTTPPort";

        /**
         * Container key names: Joram Id
         */
        public static final String CONF_JORAM_ID = "joramId";

        /**
         * Container key names: Joram Login
         */
        public static final String CONF_JORAM_LOGIN = "joramLogin";

        /**
         * Container key names: Joram Domain Port
         */
        public static final String CONF_JORAM_DOMAIN_PORT = "joramDomainPort";

        /**
         * Container key names: Joram port
         */
        public static final String CONF_JORAM_TCP_PORT = "joramTCPPort";

        /**
         * Container key names: Dream port
         */
        public static final String CONF_DREAM_TCP_PORT = "dreamTCPPort";

        /**
         * Container key names: Container state
         */
        public static final String CONF_STATE = "state";

        private ContainerKeyNames() {
            // NOP
        }
    }

    public static class ContainerStates {
        /**
         * Container State: Started
         */
        public static final String STATE_STARTED = "STARTED";

        /**
         * Container State: Stopped
         */
        public static final String STATE_STOPPED = "STOPPED";

        private ContainerStates() {
            // NOP
        }
    }

    public static class OperationNames {
        /**
         * Operation name : stop the container
         */
        public static final String STOP = "stopContainer";

        /**
         * Operation name : shutdown the container
         */
        public static final String SHUTDOWN = "shutdownContainer";

        /**
         * Operation name : retrieve containers configuration
         */
        public static final String RETRIEVE_CONTAINERS_CONFIGURATION = "retrieveContainersConfiguration";

        private OperationNames() {
            // NOP
        }
    }
    
    public static class MBean {
        /**
         * Petal Admin Service MBean name
         */
        public final static String NAME = "Petals:name=PetalsAdmin,type=service";

        /**
         * Petal Admin Service MBean object
         */
        public final static ObjectName PETALSADMIN_OBJECT_NAME = initObjectName();
        
        private static ObjectName initObjectName() {
            
            ObjectName objName = null;
            try {
                objName = new ObjectName(NAME);
            } catch (MalformedObjectNameException e) {
                // This exception can't occur
            }
            return objName;
        }

        private MBean() {
            // NOP
        }
    }
}
